.editor-placeholder{color:#ccc!important;font-family:Source Sans Pro,sans-serif;font-size:14px;left:.55rem;overflow:hidden;pointer-events:none;position:absolute;top:.6rem;-webkit-user-select:none;user-select:none}.editor-container{background-color:#fff;border-radius:.25rem;box-shadow:0 0 10px #0000001a;font-weight:400;line-height:20px;margin:0 auto;max-width:100%;text-align:left;width:100%}.editor-container,.editor-inner{display:flex;flex-direction:column;position:relative}.editor-inner{background:#fff;flex-grow:1}.editor-input{background-color:#fff;border-radius:0 0 .25rem .25rem;caret-color:#050505;color:#050505;flex-grow:1;font-family:Source Sans Pro,sans-serif;font-size:14px;line-height:1.2;outline:none;overflow-y:auto;padding:.5rem;position:relative;resize:none;tab-size:1}.editor-paragraph{margin:0;padding:0}.editor-heading-h1,.editor-heading-h2,.editor-heading-h3{margin:.25rem 0;padding:.25rem 0}.editor-heading-h1{font-size:20px}.editor-heading-h2{font-size:18px}.editor-heading-h3{font-size:16px}.editor-input ol,.editor-input ul{margin:.5rem 0;padding-left:20px}.editor-input li{margin-bottom:.25rem}.editor-input li:last-child{margin-bottom:0}.editor-input ol+p,.editor-input p+ol,.editor-input p+ul,.editor-input ul+p{margin-top:.5rem}.toolbar{background:#fff;border-bottom:1px solid #eee;border-top-left-radius:.25rem;border-top-right-radius:.25rem;display:flex;margin-bottom:1px;padding:8px 10px;position:relative;vertical-align:middle;z-index:10}.streamlit-lexical-editor{color-scheme:light}.streamlit-lexical-editor *{color:#555}.toolbar button.toolbar-item{background:none;border:0;border-radius:10px;cursor:pointer;display:flex;padding:8px;vertical-align:middle}.toolbar button.toolbar-item:disabled{cursor:not-allowed}.toolbar button.toolbar-item.spaced{margin-right:2px}.toolbar button.toolbar-item i.format{background-size:contain;display:inline-block;display:flex;height:18px;margin-top:2px;opacity:.6;vertical-align:-.25em;width:18px}.toolbar button.toolbar-item:disabled i.format{opacity:.2}.toolbar button.toolbar-item.active{background-color:#dfe8fa4d}.toolbar button.toolbar-item.active i{opacity:1}.toolbar .divider,.toolbar .toolbar-item:hover:not([disabled]){background-color:#eee}.toolbar .divider{margin:0 4px;width:1px}.toolbar .toolbar-item .text{color:#777;display:flex;font-size:14px;height:20px;line-height:20px;overflow:hidden;text-align:left;text-overflow:ellipsis;vertical-align:middle;width:200px;width:70px}.toolbar .toolbar-item .icon{background-size:contain;display:flex;height:20px;line-height:16px;margin-right:8px;-webkit-user-select:none;user-select:none;width:20px}.toolbar select.toolbar-item{background-color:#fff;border:none;border-radius:4px;color:#555;cursor:pointer;font-size:14px;margin:0 2px;padding:6px 8px;transition:background-color .2s ease}.toolbar select.toolbar-item:hover{background-color:#f0f0f0}.toolbar select.toolbar-item:focus{box-shadow:0 0 0 2px #0078d433;outline:none}.toolbar select.toolbar-item::-ms-expand{display:none}.toolbar select.toolbar-item{appearance:none;-webkit-appearance:none;-moz-appearance:none;background-image:url("data:image/svg+xml;charset=US-ASCII,%3Csvg%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%20width%3D%22292.4%22%20height%3D%22292.4%22%3E%3Cpath%20fill%3D%22%23555555%22%20d%3D%22M287%2069.4a17.6%2017.6%200%200%200-13-5.4H18.4c-5%200-9.3%201.8-12.9%205.4A17.6%2017.6%200%200%200%200%2082.2c0%205%201.8%209.3%205.4%2012.9l128%20127.9c3.6%203.6%207.8%205.4%2012.8%205.4s9.2-1.8%2012.8-5.4L287%2095c3.5-3.5%205.4-7.8%205.4-12.8%200-5-1.9-9.2-5.5-12.8z%22%2F%3E%3C%2Fsvg%3E");background-position:right 8px center;background-repeat:no-repeat;background-size:10px auto;padding-right:24px}i.undo{background-image:url(../../static/media/arrow-counterclockwise.48745dc8e6d9b1a2f8ec.svg)}i.redo{background-image:url(../../static/media/arrow-clockwise.2ba775456dd603357519.svg)}i.bold{background-image:url(../../static/media/type-bold.b3bec3f33045771f9484.svg)}i.italic{background-image:url(../../static/media/type-italic.d3971b39b0fe39a09b1b.svg)}i.underline{background-image:url(../../static/media/type-underline.b41f84ace38d530f30b9.svg)}.editor-text-bold{font-weight:700}.editor-text-italic{font-style:italic}.editor-text-underline{text-decoration:underline}.editor-text-bold.editor-text-italic{font-style:italic;font-weight:700}.editor-text-bold.editor-text-underline{font-weight:700;text-decoration:underline}.editor-text-italic.editor-text-underline{font-style:italic;text-decoration:underline}.editor-text-bold.editor-text-italic.editor-text-underline{font-style:italic;font-weight:700;text-decoration:underline}
/*# sourceMappingURL=main.e787c529.css.map*/